==> kie-pmml-models-tree-evaluator-7.54.0.Final-sources.jar: org/kie/pmml/models/tree/evaluator/PMMLTreeModelEvaluator.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package  org.kie.pmml.models.tree.evaluator;

import java.util.Map;

import org.kie.api.KieBase;
import org.kie.api.pmml.PMML4Result;
import org.kie.pmml.api.runtime.PMMLContext;
import org.kie.pmml.api.enums.PMML_MODEL;
import org.kie.pmml.evaluator.core.executor.PMMLModelEvaluator;
import org.kie.pmml.models.tree.model.KiePMMLTreeModel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.kie.pmml.api.enums.ResultCode.OK;
import static org.kie.pmml.evaluator.core.utils.Converter.getUnwrappedParametersMap;

/**
 * Default <code>PMMLModelExecutor</code> for <b>Tree</b>
 */
public class PMMLTreeModelEvaluator implements PMMLModelEvaluator<KiePMMLTreeModel> {

    private static final Logger logger = LoggerFactory.getLogger(PMMLTreeModelEvaluator.class);

    @Override
    public PMML_MODEL getPMMLModelType(){
        return PMML_MODEL.TREE_MODEL;
    }

    @Override
    public PMML4Result evaluate(final KieBase knowledgeBase,
                                final KiePMMLTreeModel model,
                                final PMMLContext pmmlContext) {
        logger.trace("evaluate {} {} {}", knowledgeBase, model, pmmlContext);
        final Map<String, Object> requestData =
                getUnwrappedParametersMap(pmmlContext.getRequestData().getMappedRequestParams());
        PMML4Result toReturn = new PMML4Result();
        String targetField = model.getTargetField();
        Object result = model.evaluate(knowledgeBase, requestData);
        toReturn.addResultVariable(targetField, result);
        toReturn.setResultObjectName(targetField);
        toReturn.setResultCode(OK.getName());
        // TODO fix with common management of outputfields ticket DROOLS-6218
        //model.getOutputFieldsMap().forEach(toReturn::addResultVariable);
        return toReturn;
    }
}

==> kie-pmml-models-tree-evaluator-9.44.0.Final-sources.jar: org/kie/pmml/models/tree/evaluator/PMMLTreeModelEvaluator.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package  org.kie.pmml.models.tree.evaluator;

import java.util.Map;

import org.kie.api.pmml.PMML4Result;
import org.kie.pmml.api.enums.PMML_MODEL;
import org.kie.pmml.api.runtime.PMMLRuntimeContext;
import org.kie.pmml.evaluator.core.executor.PMMLModelEvaluator;
import org.kie.pmml.models.tree.model.KiePMMLTreeModel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.kie.pmml.api.enums.ResultCode.OK;
import static org.kie.pmml.evaluator.core.utils.Converter.getUnwrappedParametersMap;

/**
 * Default <code>PMMLModelExecutor</code> for <b>Tree</b>
 */
public class PMMLTreeModelEvaluator implements PMMLModelEvaluator<KiePMMLTreeModel> {

    private static final Logger logger = LoggerFactory.getLogger(PMMLTreeModelEvaluator.class);

    @Override
    public PMML_MODEL getPMMLModelType(){
        return PMML_MODEL.TREE_MODEL;
    }

    @Override
    public PMML4Result evaluate(final KiePMMLTreeModel model,
                                final PMMLRuntimeContext pmmlContext) {
        logger.trace("evaluate {} {}", model, pmmlContext);
        final Map<String, Object> requestData =
                getUnwrappedParametersMap(pmmlContext.getRequestData().getMappedRequestParams());
        PMML4Result toReturn = new PMML4Result();
        String targetField = model.getTargetField();
        Object result = model.evaluate(requestData, pmmlContext);
        toReturn.addResultVariable(targetField, result);
        toReturn.setResultObjectName(targetField);
        toReturn.setResultCode(OK.getName());
        return toReturn;
    }
}
